@@ -6,6 +6,9 @@
 Preload Options
 ---------------
 
+These options are supported by all commands,
+and usually parsed before command-specific arguments.
+
 .. cmdoption:: -A, --app
 
     app instance to use (e.g. module.attr_name)
@@ -27,6 +30,10 @@ Preload Options
 Daemon Options
 --------------
 
+These options are supported by commands that can detach
+into the background (daemon).  They will be present
+in any command that also has a `--detach` option.
+
 .. cmdoption:: -f, --logfile
 
     Path to log file. If no logfile is specified, `stderr` is used.
@@ -193,7 +200,7 @@ class Command(object):
         pass
 
     def usage(self, command):
-        """Returns the command-line usage string for this app."""
+        """Returns the command line usage string for this app."""
         return '%%prog [options] %s' % (self.args, )
 
     def get_options(self):
