@@ -25,17 +25,6 @@ from .datastructures import DependencyGraph
 from .exceptions import IncompleteStream, TimeoutError
 
 
-def from_serializable(r):
-    # earlier backends may just pickle, so check if
-    # result is already prepared.
-    if not isinstance(r, ResultBase):
-        id, nodes = r
-        if nodes:
-            return GroupResult(id, [AsyncResult(id) for id, _ in nodes])
-        return AsyncResult(id)
-    return r
-
-
 class ResultBase(object):
     """Base class for all results"""
 
@@ -198,7 +187,7 @@ class AsyncResult(ResultBase):
 
     def __str__(self):
         """`str(self) -> self.id`"""
-        return self.id
+        return str(self.id)
 
     def __hash__(self):
         """`hash(self) -> hash(self.id)`"""
@@ -530,9 +519,17 @@ class ResultSet(ResultBase):
         acc = [None for _ in xrange(len(self))]
         for task_id, meta in self.iter_native(timeout=timeout,
                                               interval=interval):
+            if propagate and meta['status'] in states.PROPAGATE_STATES:
+                raise meta['result']
             acc[results.index(task_id)] = meta['result']
         return acc
 
+    def _failed_join_report(self):
+        for res in self.results:
+            if (res.backend.is_cached(res.id) and
+                    res.state in states.PROPAGATE_STATES):
+                yield res
+
     def __len__(self):
         return len(self.results)
 
@@ -709,3 +706,18 @@ class EagerResult(AsyncResult):
     @property
     def supports_native_join(self):
         return False
+
+
+def from_serializable(r, Result=AsyncResult):
+    # earlier backends may just pickle, so check if
+    # result is already prepared.
+    print('R IS: %r' % (r, ))
+    if not isinstance(r, ResultBase):
+        if isinstance(r, (list, tuple)):
+            id, nodes = r
+            if nodes:
+                return GroupResult(id, [Result(id) for id, _ in nodes])
+            return AsyncResult(id)
+        else:
+            return AsyncResult(r)
+    return r
