@@ -84,7 +84,7 @@ def find_nearest_pickleable_exception(exc):
         try:
             exc_args = getattr(exc, 'args', [])
             superexc = supercls(*exc_args)
-            pickle.dumps(superexc)
+            pickle.loads(pickle.dumps(superexc))
         except:
             pass
         else:
@@ -159,15 +159,16 @@ class UnpickleableExceptionWrapper(Exception):
 
 def get_pickleable_exception(exc):
     """Make sure exception is pickleable."""
+    try:
+        pickle.loads(pickle.dumps(exc))
+    except Exception:
+        pass
+    else:
+        return exc
     nearest = find_nearest_pickleable_exception(exc)
     if nearest:
         return nearest
-
-    try:
-        pickle.dumps(exc)
-    except Exception:
-        return UnpickleableExceptionWrapper.from_exception(exc)
-    return exc
+    return UnpickleableExceptionWrapper.from_exception(exc)
 
 
 def get_pickled_exception(exc):
