@@ -103,9 +103,6 @@ from .heartbeat import Heart
 RUN = 0x1
 CLOSE = 0x2
 
-#: Heartbeat check is called every heartbeat_seconds' / rate'.
-AMQHEARTBEAT_RATE = 2.0
-
 #: Prefetch count can't exceed short.
 PREFETCH_COUNT_MAX = 0xFFFF
 
@@ -318,6 +315,8 @@ class Consumer(object):
     # Consumer state, can be RUN or CLOSE.
     _state = None
 
+    restart_count = -1  # first start is the same as a restart
+
     def __init__(self, ready_queue,
                  init_callback=noop, send_events=False, hostname=None,
                  initial_prefetch_count=2, pool=None, app=None,
@@ -387,6 +386,7 @@ class Consumer(object):
         self.init_callback(self)
 
         while self._state != CLOSE:
+            self.restart_count += 1
             self.maybe_shutdown()
             try:
                 self.reset_connection()
@@ -398,9 +398,9 @@ class Consumer(object):
         hub.update_readers(self.connection.eventmap)
         self.connection.transport.on_poll_init(hub.poller)
 
-    def consume_messages(self, sleep=sleep, min=min, Empty=Empty,
-                         hbrate=AMQHEARTBEAT_RATE):
+    def consume_messages(self, sleep=sleep, min=min, Empty=Empty):
         """Consume messages forever (or until an exception is raised)."""
+        hbrate = self.app.conf.BROKER_HEARTBEAT_CHECKRATE
 
         with self.hub as hub:
             qos = self.qos
